@@ -1,5 +1,6 @@
 package org.gcube.portlets.widgets.ckan2zenodopublisher.server;
 
+import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -25,6 +26,7 @@ import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.CatalogueItem;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ItemTranslateError;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ItemTranslateError.ERROR_TYPE;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ZenodoError;
+import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.DOI_dv;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoFile;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoItem;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoMetadata;
@@ -54,7 +56,7 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 	 * ckan2zenodopublisher.shared.wrapped.ZenodoItem)
 	 */
 	@Override
-	public String publishOnZenodo(ZenodoItem zenodoItem) throws Exception {
+	public DOI_dv publishOnZenodo(ZenodoItem zenodoItem) throws Exception {
 		LOG.info("publishOnZenodo called");
 		try {
 
@@ -110,12 +112,22 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 			// Step 1 : metadata
 			client = new Ckan2ZenodoImpl();
 			LOG.debug("Calling updatedMetadata for: " + zenodoDepositionPreview);
+			
+			//fixing issue #26166
+			Date thePublicationDate = zenodoDepositionPreview.getMetadata().getPublication_date();
+			LOG.debug("Publication_Date before update is: " + thePublicationDate);
+			
 			zenodoDepositionPreview = client.updatedMetadata(zenodoDepositionPreview);
 
 			// Step 2 : publish Resources
 			if (toUpload.size() > 0) {
 				LOG.debug("Trying to publish the set of CKAN resources: " + toUpload.toString());
+				
+				//fixing issue #26166
+				zenodoDepositionPreview.getMetadata().setPublication_date(thePublicationDate);
+				LOG.debug("Publication_Date before uploadFiles is: " + zenodoDepositionPreview.getMetadata().getPublication_date());
 				Future<ZenodoDeposition> future_Dep = client.uploadFiles(toUpload, zenodoDepositionPreview);
+				
 				while (!future_Dep.isDone()) {
 					LOG.debug("Waiting for completed future computation (publishing of resources on Zenodo)...");
 					Thread.sleep(2000);
@@ -125,10 +137,15 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 
 			// Get the item representation
 			CkanItemDescriptor item = client.read(zenodoItem.getName());
+
+			//fixing issue #26166
+			LOG.debug("Publication_Date before publish is: " + thePublicationDate);
+			zenodoDepositionPreview.getMetadata().setPublication_date(thePublicationDate);
+			
 			// Finalize
 			LOG.debug("Calling publish on Zenodo for: " + zenodoDepositionPreview);
 			zenodoDepositionPreview = client.publish(zenodoDepositionPreview, item);
-			return zenodoDepositionPreview.getDoi();
+			return new DOI_dv(zenodoDepositionPreview.getDoi(), zenodoDepositionPreview.getDoi_url());
 
 			// throw new ZenodoException();
 
@@ -205,9 +222,9 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 			// TODO I'M WAITING FOR itemName retrieved from ckan2zenodo library
 			zenodoItem.setName(item.getItemId());
 
-			LOG.debug("zenodoItem getLicenses as list: " + zenodoItem.getMetadata().getLicenses());
-			LOG.debug("setting licenses at null");
-			zenodoItem.getMetadata().setLicenses(null);
+			LOG.debug("zenodoItem getLicenses as list: " + zenodoItem.getMetadata().getLicenseIDs());
+			//LOG.debug("setting licenses at null");
+			//zenodoItem.getMetadata().setLicenseIDs(null);
 			
 			LOG.debug("Returning item: " + zenodoItem);
 
